@@ -194,3 +194,23 @@ def test_bbox_from_filename():
   for fn in filenames:
     with pytest.raises(ValueError):
       bbox = Bbox.from_filename(fn)
+
+def test_bbox_to_filename():
+  bbx = Bbox([0,2,4], [1,3,5])
+
+  assert bbx.to_filename() == "0-1_2-3_4-5"
+  assert bbx.to_filename(None) == "0-1_2-3_4-5"
+  assert bbx.to_filename(0) == "0-1_2-3_4-5"
+  assert bbx.to_filename(1) == "0.0-1.0_2.0-3.0_4.0-5.0"
+
+  bbx = Bbox([1.1,3.2,5.49], [2.000003,4.0000000000000005,6.12372412421])
+
+  assert bbx.to_filename(3) == "1.100-2.000_3.200-4.000_5.490-6.124"
+
+
+
+
+
+
+
+
